Changelog
=========

0.2.1 (2015-11-21)
------------------

- Use nosetests instead of custom discovery
- Some fixes on Python 3 (mostly encodings)
- Improve error handling
- Validate configuration

0.2.0 (2013-08-24)
------------------

- colored diff
- Added ``--bump`` and ``--prepare`` to only perform bump or prepare
- Rely on VCS for tracking files and ensure working copy is clean
- Added option ``--nocommit``
- Ensure dry run does not write or execute anything
- Better output and error handling
- Group parameters in help
- Added optionnal hook vaidation
- Fix some Python incompatibilities (Python 2.6 and 3.X)
- More documentation

0.1.0 (2013-08-22)
------------------

- Initial release. Missing some parts but working!
